# -*- coding: utf-8 -*-
from django.conf.urls import *
from cerberos.views import *

urlpatterns = patterns('',
)

